"use strict";(self.webpackChunkjupyterlab_pygments=self.webpackChunkjupyterlab_pygments||[]).push([[568],{568:(t,e,a)=>{a.r(e),a.d(e,{default:()=>p});const p={id:"jupyterlab_pygments:plugin",autoStart:!0,activate:t=>{}}}}]);